/*
**  Simplified resource database module.
**  
**  Two databases are maintained.  The active and the defaults database.  The
**  active database contains the resource values from which current behaviour
**  is derived.  The defaults database contains the program defaults.
**  
**  The program specifies default values by either explicity placing them into
**  the defaults database, or by specifying them on fetches from the active
**  database.
**  
**  The action of using defaults involves copying the defaults database
**  resource values to the active database.
**  
**  The action of saving current settings involves writing the active database
**  to a disk file.  Restoring saved settings is done by reading the disk file
**  into the active database.
**  
**  Behavioural changes requested by the user at run time are stored in the
**  active database.  When the program needs to obtain a behavioural value
**  from the database, it calls these routines.
*/

#ifndef private
#define private static
#endif
#ifndef public
#define public
#endif

/*
**  Return the file specification of the active database disk file
*/
public char *xtsu_db_filename ( );

/*
**  Put a string resource value into the defaults database
*/
public void xtsu_db_put_default_string
(
    char *resource,	/* input */
    char *data		/* input */
);

/*
**  Put an integer resource value into the defaults database
*/
public void xtsu_db_put_default_int
(
    char *resource,
    int data
);

/*
**  Set current behaviour to default values
*/
public void xtsu_db_use_default();

/*
**  Place a string value into the active database
*/
public void xtsu_db_put_string
(
    char *resource,
    char *data
);

/*
**  Place a integer value into the active database
*/
public void xtsu_db_put_int
(
    char *resource,
    int data
);

/*
**  Obtain a string value from the active database
*/
public char *xtsu_db_get_string
(
    char *resource,
    char *defaults
);

/*
**  Obtain an integer value from the active database
*/
public int xtsu_db_get_int
(
    char *resource,
    int defaults
);

/*
**  Write or read the active database to or from the active database disk file
*/
public void xtsu_db_save_active ();
public void xtsu_db_read_active ();
